@@ -38,14 +38,20 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.</small>
 
 #   if defined (iPlatformMsys)
 #       define R_OK 0
+#       define W_OK 1
 
 static int access(const char *path, int mode) {
     const iString str = iStringLiteral(path);
     iBlock *wpath = toUtf16_String(&str);
     const DWORD attr = GetFileAttributesW(data_Block(wpath));
     delete_Block(wpath);
-    iUnused(mode);
-    return (attr == INVALID_FILE_ATTRIBUTES ? -1 : 0);
+    if (attr == INVALID_FILE_ATTRIBUTES) {
+        return -1;
+    }
+    if (mode == W_OK) {
+        return (attr & FILE_ATTRIBUTE_READONLY) ? -1 : 0;
+    }
+    return 0;
 }
 #   endif /* defined (iPlatformMsys) */
 
@@ -68,6 +74,7 @@ static int access(const char *path, int mode) {
 enum FileInfoFlags {
     exists_FileInfoFlag     = iBit(1),
     directory_FileInfoFlag  = iBit(2),
+    writable_FileInfoFlag   = iBit(3),
 };
 
 struct Impl_FileInfo {
@@ -136,8 +143,10 @@ static iBool initDirEntry_FileInfo_(iFileInfo *d, const iString *dirPath, struct
     set_String(d->path, full);
     delete_String(full);
     deinit_String(&entryName);
-    
     d->flags = exists_FileInfoFlag;
+    if (access(cstr_String(d->path), W_OK) == 0) {
+        d->flags |= writable_FileInfoFlag;
+    }
 #if defined (iPlatformHaiku)
     struct stat s;
     stat(ent->d_name, &s);
@@ -176,6 +185,10 @@ size_t size_FileInfo(const iFileInfo *d) {
 iBool isDirectory_FileInfo(const iFileInfo *d) {
     return (d->flags & directory_FileInfoFlag) != 0;
 }
+    
+iBool isWritable_FileInfo(const iFileInfo *d) {
+    return (d->flags & writable_FileInfoFlag) != 0;
+}
 
 iTime lastModified_FileInfo(const iFileInfo *d) {
     if (!isValid_Time(&d->lastModified)) {
