@@ -338,7 +338,7 @@ static void initFonts_Text_(iText *d) {
     }
     }
 #if !defined (NDEBUG)
-    printf("[Text] %zu fonts ready\n", size_Array(&d->fonts));
+    printf("[Text] %zu font variants ready\n", size_Array(&d->fonts));
 #endif
     gap_Text = iRound(gap_UI * d->contentFontSize);
 }
@@ -2114,7 +2114,7 @@ iTextMetrics draw_WrapText(iWrapText *d, int fontId, iInt2 pos, int color) {
         const int width = d->mode == word_WrapTextMode
                               ? tryAdvance_Text(fontId, text, d->maxWidth, &endPos).x
                               : tryAdvanceNoWrap_Text(fontId, text, d->maxWidth, &endPos).x;
-        notify_WrapText_(d, endPos, 0, width, iFalse);
+        notify_WrapText_(d, endPos, (iTextAttrib){ .colorId = color }, 0, width);
         drawRange_Text(fontId, pos, color, (iRangecc){ text.start, endPos });
         text.start = endPos;
         pos.y += lineHeight_Text(fontId);
